OC.L10N.register(
    "files",
    {
    "Files" : "Файлууд",
    "Upload" : "Байршуулах",
    "A new file or folder has been <strong>created</strong>" : "Файл эсвэл хавтас амжилттай <strong>үүсгэгдлээ</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл эсвэл хавтас амжилттай <strong>солигдлоо</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Файл эсвэл хавтас амжилттай <strong>устгагдлаа</strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл эсвэл хавтас амжилттай <strong>сэргээгдлээ</strong>",
    "You created %1$s" : "Та %1$s үүсгэлээ",
    "%2$s created %1$s" : "%2$s %1$s-ийг үүсгэлээ",
    "%1$s was created in a public folder" : "%1$s-ийг нийтийн хавтсанд үүсгэсэн байна",
    "You changed %1$s" : "Та %1$s-ийг өөрчиллөө",
    "%2$s changed %1$s" : "%2$s %1$s-ийг өөрчиллөө",
    "You deleted %1$s" : "Та %1$s-ийг устгалаа",
    "%2$s deleted %1$s" : "%2$s %1$s-ийг устгалаа",
    "You restored %1$s" : "Та %1$s-ийг сэргээлээ",
    "%2$s restored %1$s" : "%2$s %1$s-ийг сэргээлээ",
    "Save" : "Хадгалах",
    "Settings" : "Тохиргоо"
},
"nplurals=2; plural=(n != 1);");
